@@ -25,19 +25,23 @@ context = {
         },
         {
             "image": InlineImage(tpl, "templates/zope.png", height=Mm(10)),
-            "desc": "Zope is a leading Open Source Application Server and Content Management Framework",
+            "desc": "Zope is a leading Open Source Application Server "
+            "and Content Management Framework",
         },
         {
             "image": InlineImage(tpl, "templates/pyramid.png", height=Mm(10)),
-            "desc": "Pyramid is a lightweight Python web framework aimed at taking small web apps into big web apps.",
+            "desc": "Pyramid is a lightweight Python web framework aimed at taking "
+            "small web apps into big web apps.",
         },
         {
             "image": InlineImage(tpl, "templates/bottle.png", height=Mm(10)),
-            "desc": "Bottle is a fast, simple and lightweight WSGI micro web-framework for Python",
+            "desc": "Bottle is a fast, simple and lightweight WSGI micro web-framework "
+            "for Python",
         },
         {
             "image": InlineImage(tpl, "templates/tornado.png", height=Mm(10)),
-            "desc": "Tornado is a Python web framework and asynchronous networking library.",
+            "desc": "Tornado is a Python web framework and asynchronous networking "
+            "library.",
         },
     ],
 }
